==> ejc-cost-api-3.0.0-20221020.074723-161-sources.jar: com/ejianc/business/cost/vo/CostStatisticDetailVO.java <==
package com.ejianc.business.cost.vo;

import com.ejianc.business.cost.utils.ITreeNodeB;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

public class CostStatisticDetailVO  implements ITreeNodeB {
    private static final long serialVersionUID = 1L;
    private Long id; // 主键
    private Long costId; // 成本主键
    private String detailIndex; // 序号
    private String subjectCode; // 清单编号
    private Long parentId; // parent_id
    private String subjectName; // 清单名称
    private Integer costType; // 费用类型
    private String costTypeName; // 费用类型名称

    private BigDecimal budgetNum; // 预算工程量
    private BigDecimal costNum; // 成本工程量
    private BigDecimal noRelationCostNum; // 没有关联成本工程量

    private BigDecimal budgetTaxPrice; // 预算单价（含税）
    private BigDecimal costTaxPrice; // 成本单价（含税）
    private BigDecimal noRelationCostTaxPrice; // 没有关联成本单价

    private BigDecimal budgetTaxMny; //预算金额
    private BigDecimal costTaxMny; // 成本预算金额
    private BigDecimal noRelationTaxMny; // 没有关联成本金额

    private Boolean leafFlag; // 是否末级
    private String tid;
    private String tpid;
    private List<ITreeNodeB> children;
    private String shadowId;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    @Override
    public Long getNodeID() {
        return getId();
    }

    @Override
    public Long getParentID() {
        return parentId;
    }

    @Override
    public List<ITreeNodeB> getChildren() {
        if (children == null) {
            children = new ArrayList<>();
        }
        return children;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public void setCostId(Long costId) {
        this.costId = costId;
    }

    public Long getCostId() {
        return costId;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }


    public void setChildren(List<ITreeNodeB> children) {
        this.children = children;
    }

    public String getDetailIndex() {
        return detailIndex;
    }

    public void setDetailIndex(String detailIndex) {
        this.detailIndex = detailIndex;
    }



    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }


    public String getSubjectCode() {
        return subjectCode;
    }

    public void setSubjectCode(String subjectCode) {
        this.subjectCode = subjectCode;
    }

    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }

    public Integer getCostType() {
        return costType;
    }

    public void setCostType(Integer costType) {
        this.costType = costType;
    }

    public String getCostTypeName() {
        return costTypeName;
    }

    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    public BigDecimal getBudgetNum() {
        return budgetNum;
    }

    public void setBudgetNum(BigDecimal budgetNum) {
        this.budgetNum = budgetNum;
    }

    public BigDecimal getCostNum() {
        return costNum;
    }

    public void setCostNum(BigDecimal costNum) {
        this.costNum = costNum;
    }

    public BigDecimal getNoRelationCostNum() {
        return noRelationCostNum;
    }

    public void setNoRelationCostNum(BigDecimal noRelationCostNum) {
        this.noRelationCostNum = noRelationCostNum;
    }

    public BigDecimal getBudgetTaxPrice() {
        return budgetTaxPrice;
    }

    public void setBudgetTaxPrice(BigDecimal budgetTaxPrice) {
        this.budgetTaxPrice = budgetTaxPrice;
    }

    public BigDecimal getCostTaxPrice() {
        return costTaxPrice;
    }

    public void setCostTaxPrice(BigDecimal costTaxPrice) {
        this.costTaxPrice = costTaxPrice;
    }

    public BigDecimal getNoRelationCostTaxPrice() {
        return noRelationCostTaxPrice;
    }

    public void setNoRelationCostTaxPrice(BigDecimal noRelationCostTaxPrice) {
        this.noRelationCostTaxPrice = noRelationCostTaxPrice;
    }

    public BigDecimal getBudgetTaxMny() {
        return budgetTaxMny;
    }

    public void setBudgetTaxMny(BigDecimal budgetTaxMny) {
        this.budgetTaxMny = budgetTaxMny;
    }

    public BigDecimal getCostTaxMny() {
        return costTaxMny;
    }

    public void setCostTaxMny(BigDecimal costTaxMny) {
        this.costTaxMny = costTaxMny;
    }

    public BigDecimal getNoRelationTaxMny() {
        return noRelationTaxMny;
    }

    public void setNoRelationTaxMny(BigDecimal noRelationTaxMny) {
        this.noRelationTaxMny = noRelationTaxMny;
    }

    public Boolean getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Boolean leafFlag) {
        this.leafFlag = leafFlag;
    }



    public String getShadowId() {
        return shadowId;
    }

    public void setShadowId(String shadowId) {
        this.shadowId = shadowId;
    }
}

==> ejc-cost-api-3.0.0-20221021.012925-167-sources.jar: com/ejianc/business/cost/vo/CostStatisticDetailVO.java <==
package com.ejianc.business.cost.vo;

import com.ejianc.business.cost.utils.ITreeNodeB;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

public class CostStatisticDetailVO  implements ITreeNodeB {
    private static final long serialVersionUID = 1L;
    private Long id; // 主键
    private java.lang.Long settingId; // 主表主键ID
    private Long costId; // 成本主键
    private String detailIndex; // 序号
    private String subjectCode; // 清单编号
    private Long parentId; // parent_id
    private String subjectName; // 清单名称
    private Integer costType; // 费用类型
    private String costTypeName; // 费用类型名称

    private BigDecimal budgetNum; // 预算工程量
    private BigDecimal costNum; // 成本工程量
    private BigDecimal noRelationCostNum; // 没有关联成本工程量

    private BigDecimal budgetTaxPrice; // 预算单价（含税）
    private BigDecimal costTaxPrice; // 成本单价（含税）
    private BigDecimal noRelationCostTaxPrice; // 没有关联成本单价

    private BigDecimal budgetTaxMny; //预算金额
    private BigDecimal costTaxMny; // 成本预算金额
    private BigDecimal noRelationTaxMny; // 没有关联成本金额

    private Boolean leafFlag; // 是否末级
    private String tid;
    private String tpid;
    private List<ITreeNodeB> children;
    private String shadowId;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    @Override
    public Long getNodeID() {
        return getId();
    }

    @Override
    public Long getParentID() {
        return parentId;
    }

    @Override
    public List<ITreeNodeB> getChildren() {
        if (children == null) {
            children = new ArrayList<>();
        }
        return children;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public void setCostId(Long costId) {
        this.costId = costId;
    }

    public Long getSettingId() {
        return settingId;
    }

    public void setSettingId(Long settingId) {
        this.settingId = settingId;
    }

    public Long getCostId() {
        return costId;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }


    public void setChildren(List<ITreeNodeB> children) {
        this.children = children;
    }

    public String getDetailIndex() {
        return detailIndex;
    }

    public void setDetailIndex(String detailIndex) {
        this.detailIndex = detailIndex;
    }



    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }


    public String getSubjectCode() {
        return subjectCode;
    }

    public void setSubjectCode(String subjectCode) {
        this.subjectCode = subjectCode;
    }

    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }

    public Integer getCostType() {
        return costType;
    }

    public void setCostType(Integer costType) {
        this.costType = costType;
    }

    public String getCostTypeName() {
        return costTypeName;
    }

    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    public BigDecimal getBudgetNum() {
        return budgetNum;
    }

    public void setBudgetNum(BigDecimal budgetNum) {
        this.budgetNum = budgetNum;
    }

    public BigDecimal getCostNum() {
        return costNum;
    }

    public void setCostNum(BigDecimal costNum) {
        this.costNum = costNum;
    }

    public BigDecimal getNoRelationCostNum() {
        return noRelationCostNum;
    }

    public void setNoRelationCostNum(BigDecimal noRelationCostNum) {
        this.noRelationCostNum = noRelationCostNum;
    }

    public BigDecimal getBudgetTaxPrice() {
        return budgetTaxPrice;
    }

    public void setBudgetTaxPrice(BigDecimal budgetTaxPrice) {
        this.budgetTaxPrice = budgetTaxPrice;
    }

    public BigDecimal getCostTaxPrice() {
        return costTaxPrice;
    }

    public void setCostTaxPrice(BigDecimal costTaxPrice) {
        this.costTaxPrice = costTaxPrice;
    }

    public BigDecimal getNoRelationCostTaxPrice() {
        return noRelationCostTaxPrice;
    }

    public void setNoRelationCostTaxPrice(BigDecimal noRelationCostTaxPrice) {
        this.noRelationCostTaxPrice = noRelationCostTaxPrice;
    }

    public BigDecimal getBudgetTaxMny() {
        return budgetTaxMny;
    }

    public void setBudgetTaxMny(BigDecimal budgetTaxMny) {
        this.budgetTaxMny = budgetTaxMny;
    }

    public BigDecimal getCostTaxMny() {
        return costTaxMny;
    }

    public void setCostTaxMny(BigDecimal costTaxMny) {
        this.costTaxMny = costTaxMny;
    }

    public BigDecimal getNoRelationTaxMny() {
        return noRelationTaxMny;
    }

    public void setNoRelationTaxMny(BigDecimal noRelationTaxMny) {
        this.noRelationTaxMny = noRelationTaxMny;
    }

    public Boolean getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Boolean leafFlag) {
        this.leafFlag = leafFlag;
    }



    public String getShadowId() {
        return shadowId;
    }

    public void setShadowId(String shadowId) {
        this.shadowId = shadowId;
    }
}
